cgexplore.terms.PyramidAngleRange
=================================

.. currentmodule:: cgexplore.terms

.. autoclass:: PyramidAngleRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~PyramidAngleRange.yield_angles
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~PyramidAngleRange.type1
      ~PyramidAngleRange.type2
      ~PyramidAngleRange.type3
      ~PyramidAngleRange.element1
      ~PyramidAngleRange.element2
      ~PyramidAngleRange.element3
      ~PyramidAngleRange.angles
      ~PyramidAngleRange.angle_ks
   
   